import { Component, ChangeDetectionStrategy, Input, Output, EventEmitter, OnInit, inject, signal } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormBuilder, FormGroup, Validators, ReactiveFormsModule, FormsModule } from '@angular/forms';
import { NzFormModule } from 'ng-zorro-antd/form';
import { NzInputModule } from 'ng-zorro-antd/input';
import { NzSelectModule } from 'ng-zorro-antd/select';
import { NzButtonModule } from 'ng-zorro-antd/button';
import { NzDatePickerModule } from 'ng-zorro-antd/date-picker';
import { NzInputNumberModule } from 'ng-zorro-antd/input-number';
import { NzTagModule } from 'ng-zorro-antd/tag';
import { NzIconModule } from 'ng-zorro-antd/icon';
import { NzSpaceModule } from 'ng-zorro-antd/space';
import { NzDividerModule } from 'ng-zorro-antd/divider';
import { Job, JobFormData, JobType, JobLocation } from '../../../shared/data-access/interface/job.interface';

@Component({
  selector: 'job-form',
  standalone: true,
  imports: [
    CommonModule,
    ReactiveFormsModule,
    FormsModule,
    NzFormModule,
    NzInputModule,
    NzSelectModule,
    NzButtonModule,
    NzDatePickerModule,
    NzInputNumberModule,
    NzTagModule,
    NzIconModule,
    NzSpaceModule,
    NzDividerModule
  ],
  template: `
    <form nz-form [formGroup]="jobForm" (ngSubmit)="onSubmit()" class="tw-space-y-6">
      <!-- Basic Information -->
      <div class="tw-bg-white tw-p-6 tw-rounded-lg tw-border tw-border-gray-200">
        <h3 class="tw-text-lg tw-font-semibold tw-text-gray-900 tw-mb-4">Basic Information</h3>
        
        <div class="tw-grid tw-grid-cols-1 md:tw-grid-cols-2 tw-gap-4">
          <nz-form-item>
            <nz-form-label [nzRequired]="true">Job Title</nz-form-label>
            <nz-form-control [nzErrorTip]="'Please enter job title'">
              <input 
                nz-input 
                formControlName="title" 
                placeholder="e.g. Senior Java Developer"
                class="tw-w-full" />
            </nz-form-control>
          </nz-form-item>

          <nz-form-item>
            <nz-form-label [nzRequired]="true">Job Type</nz-form-label>
            <nz-form-control [nzErrorTip]="'Please select job type'">
              <nz-select formControlName="type" nzPlaceHolder="Select job type" class="tw-w-full">
                <nz-option nzValue="Full Time" nzLabel="Full Time"></nz-option>
                <nz-option nzValue="Part Time" nzLabel="Part Time"></nz-option>
                <nz-option nzValue="Remote" nzLabel="Remote"></nz-option>
              </nz-select>
            </nz-form-control>
          </nz-form-item>

          <nz-form-item>
            <nz-form-label [nzRequired]="true">Company Name</nz-form-label>
            <nz-form-control [nzErrorTip]="'Please enter company name'">
              <input 
                nz-input 
                formControlName="company" 
                placeholder="e.g. Rabobank"
                class="tw-w-full" />
            </nz-form-control>
          </nz-form-item>

          <nz-form-item>
            <nz-form-label>Company Website</nz-form-label>
            <nz-form-control [nzErrorTip]="'Please enter valid URL'">
              <input 
                nz-input 
                formControlName="company_url" 
                placeholder="https://www.company.com"
                class="tw-w-full" />
            </nz-form-control>
          </nz-form-item>

          <nz-form-item>
            <nz-form-label [nzRequired]="true">Location</nz-form-label>
            <nz-form-control [nzErrorTip]="'Please select location'">
              <nz-select formControlName="location" nzPlaceHolder="Select location" class="tw-w-full">
                <nz-option nzValue="Viet Nam" nzLabel="Viet Nam"></nz-option>
                <nz-option nzValue="Lao" nzLabel="Lao"></nz-option>
                <nz-option nzValue="Campuchia" nzLabel="Campuchia"></nz-option>
              </nz-select>
            </nz-form-control>
          </nz-form-item>
        </div>
      </div>

      <!-- Job Description -->
      <div class="tw-bg-white tw-p-6 tw-rounded-lg tw-border tw-border-gray-200">
        <h3 class="tw-text-lg tw-font-semibold tw-text-gray-900 tw-mb-4">Job Description</h3>
        
        <nz-form-item>
          <nz-form-label [nzRequired]="true">Description</nz-form-label>
          <nz-form-control [nzErrorTip]="'Please enter job description'">
            <textarea 
              nz-input 
              formControlName="description" 
              nzRows="6"
              placeholder="Describe the job role, responsibilities, and what you're looking for..."
              class="tw-w-full">
            </textarea>
          </nz-form-control>
        </nz-form-item>

        <nz-form-item>
          <nz-form-label>How to Apply</nz-form-label>
          <nz-form-control>
            <textarea 
              nz-input 
              formControlName="how_to_apply" 
              nzRows="3"
              placeholder="Instructions on how to apply for this job (optional)..."
              class="tw-w-full">
            </textarea>
          </nz-form-control>
        </nz-form-item>

        <nz-form-item>
          <nz-form-label>Company Logo URL</nz-form-label>
          <nz-form-control>
            <input 
              nz-input 
              formControlName="company_logo" 
              placeholder="https://example.com/logo.png (optional)"
              class="tw-w-full" />
          </nz-form-control>
        </nz-form-item>
      </div>

      <!-- Form Actions -->
      <div class="tw-flex tw-justify-end tw-space-x-4 tw-pt-6">
        <button 
          nz-button 
          nzType="default" 
          type="button"
          (click)="onCancel()">
          Cancel
        </button>
        <button 
          nz-button 
          nzType="primary" 
          type="submit"
          [nzLoading]="loading()"
          [disabled]="!jobForm.valid">
          {{ isEditMode ? 'Update Job' : 'Create Job' }}
        </button>
      </div>
    </form>
  `,
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class JobFormComponent implements OnInit {
  private readonly fb = inject(FormBuilder);

  @Input() job: Job | null = null;
  @Input() loading = signal(false);
  @Output() formSubmit = new EventEmitter<JobFormData>();
  @Output() formCancel = new EventEmitter<void>();

  jobForm!: FormGroup;
  isEditMode = false;

  ngOnInit(): void {
    console.log('JobFormComponent ngOnInit, job input:', this.job);
    this.isEditMode = !!this.job;
    console.log('Edit mode:', this.isEditMode);
    
    this.initializeForm();
    
    if (this.job) {
      this.populateForm(this.job);
    }
  }

  private initializeForm(): void {
    this.jobForm = this.fb.group({
      title: ['', [Validators.required, Validators.minLength(3)]],
      description: ['', [Validators.required, Validators.minLength(10)]],
      company: ['', [Validators.required]],
      company_url: ['', [Validators.pattern(/^https?:\/\/.+/)]],
      location: ['', [Validators.required]],
      type: ['', [Validators.required]],
      how_to_apply: [''],
      company_logo: ['']
    });
  }

  private populateForm(job: Job): void {
    console.log('Populating form with job data:', job);
    
    const formData = {
      title: job.title,
      description: job.description,
      company: job.company,
      company_url: job.company_url,
      location: job.location,
      type: job.type,
      how_to_apply: job.how_to_apply || '',
      company_logo: job.company_logo || ''
    };
    
    console.log('Form data to patch:', formData);
    this.jobForm.patchValue(formData);
    console.log('Form value after patch:', this.jobForm.value);
  }

  onSubmit(): void {
    console.log('Form submit called, valid:', this.jobForm.valid);
    console.log('Current form value:', this.jobForm.value);
    console.log('Edit mode:', this.isEditMode);
    
    if (this.jobForm.valid) {
      const formValue = this.jobForm.value;
      const jobData: JobFormData = {
        ...formValue
      };

      console.log('Emitting job data:', jobData);
      this.formSubmit.emit(jobData);
    } else {
      console.log('Form is invalid, errors:', this.jobForm.errors);
    }
  }

  onCancel(): void {
    this.formCancel.emit();
  }
}
