import { Injectable, inject } from '@angular/core';
import { CanActivate, Router, ActivatedRouteSnapshot } from '@angular/router';
import { Observable } from 'rxjs';
import { map, take } from 'rxjs/operators';
import { AuthService } from '../../../shared/data-access/service/auth.service';

@Injectable({ providedIn: 'root' })
export class AuthGuard implements CanActivate {
  private readonly authService = inject(AuthService);
  private readonly router = inject(Router);

  canActivate(route: ActivatedRouteSnapshot): Observable<boolean> {
    return this.authService.authState$.pipe(
      take(1),
      map(authState => {
        // Check if user is authenticated
        if (!authState.isAuthenticated) {
          this.router.navigate(['/login']);
          return false;
        }

        // Check role-based access if required
        const requiredRole = route.data?.['role'];
        if (requiredRole && authState.user?.role !== requiredRole) {
          this.router.navigate(['/unauthorized']);
          return false;
        }

        return true;
      })
    );
  }
}
